Plus

Trait Plus 

pub trait Plus<T> {
    type Output;
}
Add two peano numbers together.

This is used to determine the number of times a table appears in a from clause when the from clause contains a join.

Required Associated Types

type Output

The result of adding these numbers together

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors