pub trait QueryRelation:
QuerySource
+ AsQuery
+ Sized {
type AllColumns: SelectableExpression<Self> + ValidGrouping<()>;
// Required method
fn all_columns() -> Self::AllColumns;
}Expand description
A SQL database relation that can be queried
This includes tables and database views
Types which implement this trait are usually generated by the table! macro
Required Associated Types
Sourcetype AllColumns: SelectableExpression<Self> + ValidGrouping<()>
type AllColumns: SelectableExpression<Self> + ValidGrouping<()>
The type returned by all_columns
Required Methods
Sourcefn all_columns() -> Self::AllColumns
fn all_columns() -> Self::AllColumns
Returns a tuple of all columns belonging to this table.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".