SizeRestrictedColumn

Trait SizeRestrictedColumn 

pub trait SizeRestrictedColumn: Column {
    const MAX_LENGTH: usize;
}
Max length for columns of type Char/Varchar…

If a given column has a such constraint, this trait will be implemented and specify that length.

Required Associated Constants

const MAX_LENGTH: usize

Max length of that column

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors