pub trait ColumnHasTable {
type Table;
// Required methods
fn table(&self) -> Self::Table;
fn name(&self) -> &str;
}Expand description
A helper trait to access associated information for a given column
Usually you want to use the QueryFragment implementation for
your column type to construct a correctly quoted query
fragment containing the fully qualified identifier
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".